@@ -4,7 +4,6 @@
 pub const NFT_ACCOUNT_SIZE:usize = 99;
 
 
-
 // Distribut account constants.
 /// The size of distribute token account 
 pub const DISTRIBUTE_TOKEN_SIZE:usize = 1882;
@@ -36,9 +35,17 @@ pub const PORTFOLIO_PREFIX: usize = 213;
 pub const ASSET_LEN: usize = 67;
 
 
-
 // User Portfolio account constatnts.
 /// LEN of constant prefix of user portfolio account.
-pub const USER_PORTFOLIO_PREFIX: usize = 236;
+pub const USER_PORTFOLIO_PREFIX: usize = 227;
 /// The size of splu user portfolio struct.
-pub const SPLU_LEN: usize = 164;
\ No newline at end of file
+pub const SPLU_LEN: usize = 161;
+
+/// The size of Turing account 
+pub const TURING_ACCOUNT_PREFIX:usize = 75;
+
+/// The size of splu secondary state of Turing account 
+pub const SPLU_SECONDARY_STRUCT_LEN:usize = 1;
+
+/// The size of splu tertiary state of Turing account 
+pub const SPLU_TERTAIRY_STRUCT_LEN:usize = 2;
\ No newline at end of file
