@@ -9,23 +9,16 @@ use solana_program::{
 };
 use std::vec::Vec;
 
-use crate::{
+use crate::
     constants::{
         account_size::{SPLU_LEN, USER_PORTFOLIO_PREFIX},
-        constant::{NULL_PUBKEY, PUBKEY_SIZE},
+        constant:: PUBKEY_SIZE,
         account_type::TYPE_ACCOUNT_USER_PORTFOLIO_ACCOUNT,
-    },
-    error::PortfolioError,
 };
 
 const TYPE_SIZE: usize = 1;
-const STATE_SIZE: usize = 1;
-const AMOUNT_SIZE: usize = 8;
 const VERSION_SIZE: usize = 1;
 const NONCE_SIZE: usize = 1;
-const STATE_SPLU_SECONDARY: usize = 1;
-const STATE_SPLU_TERTIARY1: usize = 1;
-const STATE_SPLU_TERTIARY2: usize = 1;
 const NONCE_SPLU: usize = 1;
 
 /// struct of SPLU of PPU
@@ -34,16 +27,10 @@ const NONCE_SPLU: usize = 1;
 pub struct SpluStruct {
     /// SPLU secondary address.
     pub splu_secondary: Pubkey,
-    /// State of SPLU secondary.
-    pub state_splu_secondary: u8,
     /// First SPLU tertiary address.
     pub splu_tertiary1: Pubkey,
     /// State of first SPLU tertiary.
-    pub state_splu_tertiary1: u8,
-    /// Second SPLU tertiary address.
     pub splu_tertiary2: Pubkey,
-    /// State of second SPLU tertiary.
-    pub state_splu_tertiary2: u8,
     /// Authority of SPLU.
     pub authority_splu: Pubkey,
     /// Account_program of SPLU.
@@ -62,7 +49,6 @@ impl SpluStruct {
         nonce_splu: u8,
     ) -> ProgramResult {
         self.splu_secondary = splu_secondary_address;
-        self.state_splu_secondary = 1;
         self.authority_splu = authority_splu;
         self.program_account_splu = program_account_splu;
         self.nonce_splu = nonce_splu;
@@ -70,23 +56,6 @@ impl SpluStruct {
         Ok(())
     }
 
-    /// update the state of splu secondary
-    pub fn update_splu_secondary(&mut self) -> ProgramResult {
-        self.state_splu_secondary = self
-            .state_splu_secondary
-            .checked_add(1)
-            .ok_or(PortfolioError::InvalidAmount)?;
-
-        Ok(())
-    }
-
-    /// reset the state of splu secondary
-    pub fn reset_splu_secondary(&mut self) -> ProgramResult {
-        self.state_splu_secondary = 0;
-
-        Ok(())
-    }
-
     /// add new splu teriary
     pub fn add_splu_tertiary(
         &mut self,
@@ -94,35 +63,11 @@ impl SpluStruct {
         splu_tertiary2: Pubkey,
     ) -> ProgramResult {
         self.splu_tertiary1 = splu_tertiary1;
-        self.state_splu_tertiary1 = self
-            .state_splu_tertiary1
-            .checked_add(1)
-            .ok_or(PortfolioError::InvalidAmount)?;
         self.splu_tertiary2 = splu_tertiary2;
-        if splu_tertiary2.as_ref() != NULL_PUBKEY {
-            self.state_splu_tertiary2 = self
-                .state_splu_tertiary2
-                .checked_add(1)
-                .ok_or(PortfolioError::InvalidAmount)?;
-        }
+  
         Ok(())
     }
 
-    /// reset the state of splu teriary
-    pub fn reset_splu_tertiary(&mut self) -> ProgramResult {
-        self.state_splu_tertiary1 = 0;
-        self.state_splu_tertiary2 = 0;
-
-        Ok(())
-    }
-
-    /// update the state splu teriary
-    pub fn update_state_tertiary(&mut self, state1: u8, state2: u8) -> ProgramResult {
-        self.state_splu_tertiary1 = state1;
-        self.state_splu_tertiary2 = state2;
-
-        Ok(())
-    }
 }
 
 ///  User Portfolio data.
@@ -138,10 +83,6 @@ pub struct UserPortfolio {
     pub portfolio_address: Pubkey,
     /// The asset minted while join.
     pub splm_n_asset: Pubkey,
-    /// State of PPU to know which step was completed.
-    pub state: u8,
-    /// Last amount deposit or withraw.
-    pub amount: u64,
     /// Version of PPU struct.
     pub version: u8,
     /// Account to be used to save extra data.
@@ -186,8 +127,6 @@ impl PackUserPortfolio for UserPortfolio {
             owner,
             portfolio_address,
             splm_n_asset,
-            state,
-            amount,
             version,
             extended_data,
             splm_primary,
@@ -200,8 +139,6 @@ impl PackUserPortfolio for UserPortfolio {
             PUBKEY_SIZE,
             PUBKEY_SIZE,
             PUBKEY_SIZE,
-            STATE_SIZE,
-            AMOUNT_SIZE,
             VERSION_SIZE,
             PUBKEY_SIZE,
             PUBKEY_SIZE,
@@ -222,33 +159,24 @@ impl PackUserPortfolio for UserPortfolio {
             #[allow(clippy::ptr_offset_with_cast)]
             let (
                 splu_secondary,
-                state_splu_secondary,
                 splu_tertiary1,
-                state_splu_tertiary1,
                 splu_tertiary2,
-                state_splu_tertiary2,
                 authority_splu,
                 program_account_splu,
                 nonce_splu,
             ) = array_refs![
                 splu_data,
                 PUBKEY_SIZE,
-                STATE_SPLU_SECONDARY,
                 PUBKEY_SIZE,
-                STATE_SPLU_TERTIARY1,
                 PUBKEY_SIZE,
-                STATE_SPLU_TERTIARY2,
                 PUBKEY_SIZE,
                 PUBKEY_SIZE,
                 NONCE_SPLU
             ];
             splu_vec.push(SpluStruct {
                 splu_secondary: Pubkey::new_from_array(*splu_secondary),
-                state_splu_secondary: u8::from_le_bytes(*state_splu_secondary),
                 splu_tertiary1: Pubkey::new_from_array(*splu_tertiary1),
-                state_splu_tertiary1: u8::from_le_bytes(*state_splu_tertiary1),
                 splu_tertiary2: Pubkey::new_from_array(*splu_tertiary2),
-                state_splu_tertiary2: u8::from_le_bytes(*state_splu_tertiary2),
                 authority_splu: Pubkey::new_from_array(*authority_splu),
                 program_account_splu: Pubkey::new_from_array(*program_account_splu),
                 nonce_splu: u8::from_le_bytes(*nonce_splu),
@@ -261,8 +189,6 @@ impl PackUserPortfolio for UserPortfolio {
             owner: Pubkey::new_from_array(*owner),
             portfolio_address: Pubkey::new_from_array(*portfolio_address),
             splm_n_asset: Pubkey::new_from_array(*splm_n_asset),
-            state: u8::from_le_bytes(*state),
-            amount: u64::from_le_bytes(*amount),
             version: u8::from_le_bytes(*version),
             extended_data: Pubkey::new_from_array(*extended_data),
             splm_primary: Pubkey::new_from_array(*splm_primary),
@@ -280,8 +206,6 @@ impl PackUserPortfolio for UserPortfolio {
             owner,
             portfolio_address,
             splm_n_asset,
-            state,
-            amount,
             version,
             extended_data,
             splm_primary,
@@ -301,22 +225,15 @@ impl PackUserPortfolio for UserPortfolio {
         let splm_n_asset_range =
             TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE..TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE;
         buffer[splm_n_asset_range].clone_from_slice(splm_n_asset.as_ref());
-        let state_range = TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE;
-        buffer[state_range] = *state;
-        let amount_range = TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + STATE_SIZE
-            ..TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + STATE_SIZE + AMOUNT_SIZE;
-        let amount_to_array = amount.to_le_bytes();
-        buffer[amount_range].clone_from_slice(&amount_to_array[0..]);
-        let version_range = TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + STATE_SIZE + AMOUNT_SIZE;
+       
+        let version_range = TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE;
         buffer[version_range] = *version;
         let extended_data_range =
-            TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + STATE_SIZE + AMOUNT_SIZE + VERSION_SIZE
+            TYPE_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + PUBKEY_SIZE + VERSION_SIZE
                 ..TYPE_SIZE
                 + PUBKEY_SIZE
                     + PUBKEY_SIZE
                     + PUBKEY_SIZE
-                    + STATE_SIZE
-                    + AMOUNT_SIZE
                     + VERSION_SIZE
                     + PUBKEY_SIZE;
         buffer[extended_data_range].clone_from_slice(extended_data.as_ref());
@@ -324,16 +241,12 @@ impl PackUserPortfolio for UserPortfolio {
          + PUBKEY_SIZE
             + PUBKEY_SIZE
             + PUBKEY_SIZE
-            + STATE_SIZE
-            + AMOUNT_SIZE
             + VERSION_SIZE
             + PUBKEY_SIZE
             ..TYPE_SIZE
             + PUBKEY_SIZE
                 + PUBKEY_SIZE
                 + PUBKEY_SIZE
-                + STATE_SIZE
-                + AMOUNT_SIZE
                 + VERSION_SIZE
                 + PUBKEY_SIZE
                 + PUBKEY_SIZE;
@@ -342,8 +255,6 @@ impl PackUserPortfolio for UserPortfolio {
         + PUBKEY_SIZE
             + PUBKEY_SIZE
             + PUBKEY_SIZE
-            + STATE_SIZE
-            + AMOUNT_SIZE
             + VERSION_SIZE
             + PUBKEY_SIZE
             + PUBKEY_SIZE
@@ -351,8 +262,6 @@ impl PackUserPortfolio for UserPortfolio {
             + PUBKEY_SIZE
                 + PUBKEY_SIZE
                 + PUBKEY_SIZE
-                + STATE_SIZE
-                + AMOUNT_SIZE
                 + VERSION_SIZE
                 + PUBKEY_SIZE
                 + PUBKEY_SIZE
@@ -362,8 +271,6 @@ impl PackUserPortfolio for UserPortfolio {
         + PUBKEY_SIZE
             + PUBKEY_SIZE
             + PUBKEY_SIZE
-            + STATE_SIZE
-            + AMOUNT_SIZE
             + VERSION_SIZE
             + PUBKEY_SIZE
             + PUBKEY_SIZE
@@ -373,8 +280,6 @@ impl PackUserPortfolio for UserPortfolio {
         + PUBKEY_SIZE
             + PUBKEY_SIZE
             + PUBKEY_SIZE
-            + STATE_SIZE
-            + AMOUNT_SIZE
             + VERSION_SIZE
             + PUBKEY_SIZE
             + PUBKEY_SIZE
@@ -384,8 +289,6 @@ impl PackUserPortfolio for UserPortfolio {
              + PUBKEY_SIZE
                 + PUBKEY_SIZE
                 + PUBKEY_SIZE
-                + STATE_SIZE
-                + AMOUNT_SIZE
                 + VERSION_SIZE
                 + PUBKEY_SIZE
                 + PUBKEY_SIZE
@@ -419,11 +322,8 @@ mod tests {
     fn test_pack_unpack_user_portfolio() {
         let splu_struct = SpluStruct {
             splu_secondary: Pubkey::new_unique(),
-            state_splu_secondary: 1,
             splu_tertiary1: Pubkey::new_unique(),
-            state_splu_tertiary1: 1,
             splu_tertiary2: Pubkey::new_unique(),
-            state_splu_tertiary2: 1,
             authority_splu: Pubkey::new_unique(),
             program_account_splu: Pubkey::new_unique(),
             nonce_splu: 1,
@@ -437,8 +337,6 @@ mod tests {
             owner: Pubkey::new_unique(),
             portfolio_address: Pubkey::new_unique(),
             splm_n_asset: Pubkey::new_unique(),
-            state: 2,
-            amount: 3,
             version: 1,
             extended_data: Pubkey::new_unique(),
             splm_primary: Pubkey::new_unique(),
